``0x10c-asm`` assembly compiler for Notch's DCPU-16
---------------------------------------------------

Install from Pypi:
==================

  pip install 0x10c-asm

Usage:
======

  $ 0x10c-asm.py -h

  usage: ``0x10-asm.py [-h] IN [OUT]``

  A simple Python-based DCPU assembly compiler

  positional arguments:
    ``IN``          file path of the file containing the assembly code

    ``OUT``         file path where to store the binary code

  optional arguments:
    -h, --help  show this help message and exit

